@@ -65,7 +65,7 @@ OnepModel<-structure(
       Ex=OnepModel(t,k,C0,In)
       Ct=getC(Ex)
       Rt=getReleaseFlux(Ex)
-      Rc=getRelease(Ex)
+      Rc=getAccumulatedRelease(Ex)
       
       plot(t,Ct,type="l",ylab="Carbon stocks (arbitrary units)",xlab="Time (arbitrary units)",lwd=2) 
       
